# Mscan

<img with="150px" height="150px" src="https://user-images.githubusercontent.com/61390950/182006521-350c306a-2567-49eb-b77a-42224783768f.png">  

## A modern network scanner
## 🖥 User Interface
![image](https://user-images.githubusercontent.com/61390950/182006567-5e5cfcbe-7549-4205-902e-54706d2c1793.png)


## ✨ Features

- 🕹 Simple and clear user interface
- 🚀 Super fast
- 🛠 More features in development
